@@ -3,13 +3,15 @@
 import abc
 import enum
 import functools
+import json
+
 import attr
 
 import six
 
-from cryptoparser.common.base import Serializable
+from cryptoparser.common.base import ProtocolVersionBase
 from cryptoparser.common.exception import NotEnoughData, InvalidValue
-from cryptoparser.common.parse import ParsableBase, ParserBinary, ComposerBinary
+from cryptoparser.common.parse import ParserBinary, ComposerBinary
 
 
 class TlsVersion(enum.IntEnum):
@@ -21,9 +23,8 @@ class TlsVersion(enum.IntEnum):
 
 
 @attr.s(order=False, eq=False, hash=True)
-@six.add_metaclass(abc.ABCMeta)
 @functools.total_ordering
-class TlsProtocolVersionBase(Serializable, ParsableBase):
+class TlsProtocolVersionBase(ProtocolVersionBase):
     _SIZE = 2
 
     major = attr.ib()
@@ -69,12 +70,6 @@ class TlsProtocolVersionBase(Serializable, ParsableBase):
 
         return isinstance(self, TlsProtocolVersionDraft) == (other.minor == TlsVersion.TLS1_3)
 
-    def _asdict(self):
-        return self.identifier
-
-    def _as_markdown(self, level):
-        return self._markdown_result(str(self), level)
-
     @property
     @abc.abstractmethod
     def identifier(self):
@@ -168,19 +163,19 @@ class SslVersion(enum.IntEnum):
 
 @attr.s(eq=True, order=False, hash=True)
 @functools.total_ordering
-class SslProtocolVersion(Serializable, ParsableBase):
+class SslProtocolVersion(ProtocolVersionBase):
     _SIZE = 2
 
     def __lt__(self, other):
         return isinstance(other, TlsProtocolVersionBase)
 
+    def as_json(self):
+        return json.dumps(self.identifier)
+
     @property
     def identifier(self):
         return 'ssl2'
 
-    def _asdict(self):
-        return self.identifier
-
     def __str__(self):
         return 'SSL 2.0'
 
